@@ -170,7 +170,7 @@ class Cellpose():
             else:
                 if rescale is None:
                     if do_3D:
-                        rescale = 1.0
+                        rescale = np.ones(1)
                     else:
                         rescale = np.ones(len(x), np.float32)
                 diams = self.diam_mean / rescale.copy() / (np.pi**0.5/2)
@@ -490,13 +490,13 @@ class CellposeModel():
             
         """
         IMG, ysub, xsub, Ly, Lx = transforms.make_tiles(imgi, bsize, augment=True)
-        IMG = nd.array(IMG, ctx=self.device)
         nbatch = self.batch_size
         niter = int(np.ceil(IMG.shape[0]/nbatch))
         y = np.zeros((IMG.shape[0], 3, bsize, bsize))
         for k in range(niter):
             irange = np.arange(nbatch*k, min(IMG.shape[0], nbatch*k+nbatch))
-            y0, style = self.net(IMG[irange])
+            img = nd.array(IMG[irange], ctx=self.device)
+            y0, style = self.net(img)
             y[irange] = y0.asnumpy()
             if k==0:
                 styles = style.asnumpy()[0]
@@ -650,12 +650,15 @@ class CellposeModel():
         if save_path is not None:
             _, file_label = os.path.split(save_path)
             file_path = os.path.join(save_path, 'models/')
+
+            if not os.path.exists(file_path):
+                os.makedirs(file_path)
         else:
             print('WARNING: no save_path given, model not saving')
+
         ksave = 0
-        if not os.path.exists(file_path):
-            os.makedirs(file_path)
         rsc = 1.0
+
         for iepoch in range(self.n_epochs):
             np.random.seed(iepoch)
             rperm = np.random.permutation(nimg)
